@@ -22,7 +22,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *   along with this program.  If not, see www.gnu.org/licenses/.
  */
 
 
@@ -35,7 +35,8 @@
 #define VALUE_DICTIONARY_SIZE  20
 
 #define FULL_RESULTS 0
-#define WINDOW_SIZE 1000000
+/* WINDOW_SIZE must be set unless the maximum trace size is known! */
+#define WINDOW_SIZE 0
 #define PURGE_THRESHOLD 0.5
 #ifndef TARGET
 #define TARGET linux
@@ -53,6 +54,7 @@
 #include <stdarg.h>
 #include <stdint.h>
 #include <inttypes.h>
+#include <float.h>
 #define NO_DYNAMIC_MEMORY
 
 
@@ -61,14 +63,4 @@
 #include <stdio.h>
 #endif
 
-// Erika defines
-#if TARGET==erika
-#define NO_STDLIB
-#define NO_STDIO
-#include <mach.h>
-#include "ee_internal.h"
-#include "ee_assert.h"
-#include "ee_oo_api_extension.h"
-#include <inmate.h>
-#define HAS_BOOL
-#endif
+// other target defines go here
